summaryrefslogtreecommitdiff
path: root/alot/walker.py
diff options
context:
space:
mode:
authorLucas Hoffmann <l-m-h@web.de>2017-02-26 14:06:27 +0100
committerLucas Hoffmann <l-m-h@web.de>2017-02-26 14:06:27 +0100
commitec50a914e91712cf55f1e919d829834e92a76b38 (patch)
tree5f477eee82255ef401d25b4324b0fdb93a406bc0 /alot/walker.py
parentdaaee433bf64c0b6a4b2c5e1149c7538e2a2ea64 (diff)
Mention "public" attributes in class docstring
Diffstat (limited to 'alot/walker.py')
-rw-r--r--alot/walker.py8
1 files changed, 6 insertions, 2 deletions
diff --git a/alot/walker.py b/alot/walker.py
index 381976ae..a26b2926 100644
--- a/alot/walker.py
+++ b/alot/walker.py
@@ -8,8 +8,12 @@ import urwid
class PipeWalker(urwid.ListWalker):
- """urwid.ListWalker that reads next items from a pipe and
- wraps them in `containerclass` widgets for displaying
+ """urwid.ListWalker that reads next items from a pipe and wraps them in
+ `containerclass` widgets for displaying
+
+ Atributes that should be considered publicly readable:
+ :attr lines: the lines obtained from the pipe
+ :type lines: list(`containerclass`)
"""
def __init__(self, pipe, containerclass, reverse=False, **kwargs):
self.pipe = pipe